@@ -1,8 +1,8 @@
 /*
- * NASPRO - The NASPRO Architecture for Sound Processing
+ * NASPRO - The NASPRO Architecture for Sound PROcessing
  * LV2 bridging helper library
  *
- * Copyright (C) 2007-2012 NASPRO Bridge it development team
+ * Copyright (C) 2007-2013 NASPRO Bridge it development team
  *
  * See the COPYING file for license conditions.
  */
@@ -10,18 +10,19 @@
 /*
    Title: NASPRO Bridge it
 
-   *Version*: 0.4.1, *API*: 3.0.0.
+   *Version*: 0.5.0, *API*: 3.0.0.
 
    About:
 
-     <NASPRO Bridge it at http://naspro.atheme.org/libraries/naspro-bridge-it/>
-     is a little helper library to develop <insert-your-API-here> to LV2 bridges.
+     <NASPRO Bridge it at
+     http://naspro.sourceforge.net/libraries.html#naspro-bridge-it> is a little
+     helper library to develop <insert-your-API-here> to LV2 bridges.
 
      As of now, it basically offers a few utility functions and Turtle/RDF
      serialization for LV2 dynamic manifest generation, supporting the following
      LV2 extensions.
 
-       * <LV2 at http://lv2plug.in/ns/lv2core> >= 4.0;
+       * <LV2 at http://lv2plug.in/ns/lv2core/> >= 4.0;
        * <LV2 Dynamic Manifest at http://lv2plug.in/ns/ext/dynmanifest/> >= 1.0;
        * <LV2 Port Properties at http://lv2plug.in/ns/ext/port-props/> >= 1.0
          (only for the logarithmic port property);
@@ -33,8 +34,9 @@
    Supported platforms/compilers:
 
      It is written in C99 and there is no platform- or compiler-specific code,
-     hence wherever <NASPRO core at http://naspro.atheme.org/naspro-core/> runs,
-     this library is able to run.
+     hence wherever <NASPRO core at
+     http://naspro.sourceforge.net/libraries.html#naspro-core> runs, this
+     library is able to run.
 
    API conventions:
 
@@ -48,8 +50,7 @@
 
    Runtime dependencies:
 
-     * <NASPRO core at http://naspro.atheme.org/libraries/naspro-core/> >=
-       0.4.0.
+     * NASPRO core >= 0.4.0.
 
    Build-time dependencies:
 
